Documentation
¶
Overview ¶
Package lang provides some helpful or at least amusing language features not included in the standard Go language or libraries.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Head ¶ added in v0.0.5
Head returns up to the first count elements in the given input slice.
Note that this is yields a shallow copy.
func Map ¶ added in v0.0.3
func Map[A, B any](input []A, f func(A) B) []B
Map applies function f to every A element in input to create a new slice of type B.
Types ¶
Click to show internal directories.
Click to hide internal directories.