Documentation
¶
Overview ¶
Package lang provides some helpful or at least amusing language features not included in the standard Go language or libraries.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Head ¶ added in v0.0.5
Head returns up to the first count elements in the given input slice.
Note that this is yields a shallow copy.
Types ¶
Click to show internal directories.
Click to hide internal directories.